============
Introduction
============


Requisites
----------

{{project}} requires Python >= 3.3


Installation
------------

.. code-block:: bash

    pip install {{project}}


Basic usage
-----------

